NetHack Learning Environment (NLE) Documentation
================================================

The NetHack Learning Environment (NLE) is an environment designed for machine
learning and reinforcement learning research.

It provides a standard, synchronous, reinforcement learning interface around the
normal user (visual) interface of NetHack `3.6.6`.

The game dynamics are largely unchanged, and the control interface mostly
resembles the one used by people when playing the game.


.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   getting_started


.. toctree::
   :maxdepth: 3
   :caption: Python API

   nle



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
